@@ -8,11 +8,15 @@ from . import well_architected_stack
 class ApiLambdaEventBridgeLambda(well_architected_stack.Stack):
 
     def __init__(self, scope: constructs.Construct, id: str,
+        create_http_api=None,
+        create_rest_api=None,
+        lambda_directory=None,
         **kwargs
     ) -> None:
         super().__init__(scope, id, **kwargs)
         self.create_error_topic()
-        self.create_lambda_function(
+        self.lambda_directory = lambda_directory
+        self.approved_transaction = self.create_lambda_construct(
             handler_name="approved_transaction_handler",
             function_name="atm_consumer",
             event_bridge_rule=self.create_event_bridge_rule(
@@ -24,7 +28,7 @@ class ApiLambdaEventBridgeLambda(well_architected_stack.Stack):
             ),
         )
 
-        self.create_lambda_function(
+        self.ny_prefix_transaction = self.create_lambda_construct(
             handler_name="ny_prefix_transaction_handler",
             function_name="atm_consumer",
             event_bridge_rule=self.create_event_bridge_rule(
@@ -35,7 +39,7 @@ class ApiLambdaEventBridgeLambda(well_architected_stack.Stack):
             ),
         )
 
-        self.create_lambda_function(
+        self.not_approved_transaction = self.create_lambda_construct(
             handler_name="not_approved_transaction_handler",
             function_name="atm_consumer",
             event_bridge_rule=self.create_event_bridge_rule(
@@ -46,11 +50,16 @@ class ApiLambdaEventBridgeLambda(well_architected_stack.Stack):
             ),
         )
 
-        atm_producer_lambda = self.create_lambda_function(
-            function_name="atm_producer",
+        self.atm_producer = well_architected_constructs.api_lambda.ApiLambda(
+            self, 'AtmProducer',
+            function_name='atm_producer',
+            create_http_api=create_http_api,
+            create_rest_api=create_rest_api,
+            lambda_directory=lambda_directory,
+            error_topic=self.error_topic,
         )
 
-        atm_producer_lambda.add_to_role_policy(
+        self.atm_producer.lambda_function.add_to_role_policy(
             aws_cdk.aws_iam.PolicyStatement(
                 effect=aws_cdk.aws_iam.Effect.ALLOW,
                 resources=['*'],
@@ -58,13 +67,12 @@ class ApiLambdaEventBridgeLambda(well_architected_stack.Stack):
             )
         )
 
-        well_architected_constructs.api_lambda.create_rest_api_lambda(
-            self, error_topic=self.error_topic,
-            lambda_function=atm_producer_lambda
-        )
-        well_architected_constructs.api_lambda.create_http_api_lambda(
-            self, error_topic=self.error_topic,
-            lambda_function=atm_producer_lambda
+        self.create_cloudwatch_dashboard(
+            *self.approved_transaction.create_cloudwatch_widgets(),
+            *self.ny_prefix_transaction.create_cloudwatch_widgets(),
+            *self.not_approved_transaction.create_cloudwatch_widgets(),
+            *self.atm_producer.lambda_construct.create_cloudwatch_widgets(),
+            *self.atm_producer.api_construct.create_cloudwatch_widgets(),
         )
 
     def create_event_bridge_rule(self, rule_name=None, description=None, detail=None):
@@ -78,15 +86,15 @@ class ApiLambdaEventBridgeLambda(well_architected_stack.Stack):
             )
         )
 
-    def create_lambda_function(
+    def create_lambda_construct(
         self, handler_name='handler', function_name=None,
         event_bridge_rule:aws_cdk.aws_events.Rule=None,
     ):
-        return well_architected_constructs.lambda_function.LambdaFunctionConstruct(
+        return well_architected_constructs.lambda_function.LambdaFunction(
             self, handler_name,
             handler_name=handler_name,
             function_name=function_name,
             event_bridge_rule=event_bridge_rule,
             error_topic=self.error_topic,
             lambda_directory=self.lambda_directory,
-        ).lambda_function
+        )
