@@ -7,42 +7,46 @@ from . import well_architected_stack
 
 class ApiLambdaSqsLambdaDynamodb(well_architected_stack.Stack):
 
-    def __init__(self, scope: constructs.Construct, id: str, **kwargs) -> None:
+    def __init__(
+        self, scope: constructs.Construct, id: str,
+        **kwargs
+    ) -> None:
         super().__init__(scope, id, **kwargs)
         self.create_error_topic()
-        dynamodb_table = self.create_dynamodb_table(
-            partition_key="id",
-        )
 
         sqs_queue = aws_cdk.aws_sqs.Queue(
             self, 'SqsQueue',
             visibility_timeout=aws_cdk.Duration.seconds(300)
         )
 
-        self.create_sqs_subscribing_lambda(
-            sqs_queue=sqs_queue,
-            dynamodb_table=dynamodb_table,
+        sqs_subscriber = well_architected_constructs.api_lambda_dynamodb.ApiLambdaDynamodb(
+            self, 'LambdaDynamodb',
+            function_name='api_lambda_sqs_lambda_dynamodb_subscriber',
+            partition_key="id",
+            lambda_directory=self.lambda_directory,
+            error_topic=self.error_topic,
+            create_http_api=self.create_http_api,
+            create_rest_api=self.create_rest_api,
+            concurrent_executions=2,
+            environment_variables={
+                'SQS_QUEUE_URL': sqs_queue.queue_url,
+            },
         )
 
-        sqs_publishing_lambda = self.create_sqs_publishing_lambda(sqs_queue)
+        sqs_subscriber.lambda_function.add_event_source(aws_cdk.aws_lambda_event_sources.SqsEventSource(sqs_queue))
+        sqs_queue.grant_consume_messages(sqs_subscriber.lambda_function)
+        sqs_subscriber.dynamodb_table.grant_read_write_data(sqs_subscriber.lambda_function)
 
-        well_architected_constructs.api_lambda.create_http_api_lambda(
-            self, lambda_function=sqs_publishing_lambda,
-            error_topic=self.error_topic,
-        )
-        well_architected_constructs.api_lambda.create_rest_api_lambda(
-            self, lambda_function=sqs_publishing_lambda,
-            error_topic=self.error_topic,
+        sqs_publisher = self.create_sqs_publishing_lambda(sqs_queue)
+
+        self.create_cloudwatch_dashboard(
+            *sqs_subscriber.api_construct.create_cloudwatch_widgets(),
+            *sqs_subscriber.lambda_construct.create_cloudwatch_widgets(),
+            *sqs_subscriber.dynamodb_construct.create_cloudwatch_widgets(),
+            *sqs_publisher.create_cloudwatch_widgets(),
         )
 
-    def create_dynamodb_table(self, partition_key):
-        return well_architected_constructs.dynamodb_table.DynamodbTableConstruct(
-            self, "DynamodbTable",
-            partition_key=partition_key,
-            error_topic=self.error_topic,
-        ).dynamodb_table
-
-    def create_lambda_function(
+    def create_lambda_construct(
         self, function_name=None,
         environment_variables=None, concurrent_executions=None,
     ):
@@ -57,20 +61,21 @@ class ApiLambdaSqsLambdaDynamodb(well_architected_stack.Stack):
     def create_sqs_publishing_lambda(
         self, sqs_queue:aws_cdk.aws_sqs.Queue
     ):
-        lambda_function = self.create_lambda_function(
+        lambda_construct = self.create_lambda_construct(
             function_name='api_lambda_sqs_lambda_dynamodb_publisher',
             environment_variables={
                 'SQS_QUEUE_URL': sqs_queue.queue_url
             },
         )
+        lambda_function = lambda_construct.lambda_function
         sqs_queue.grant_send_messages(lambda_function)
-        return lambda_function
+        return lambda_construct
 
     def create_sqs_subscribing_lambda(
         self, sqs_queue: aws_cdk.aws_sqs.Queue=None,
         dynamodb_table:aws_cdk.aws_dynamodb.Table=None,
     ):
-        lambda_function = self.create_lambda_function(
+        lambda_construct = self.create_lambda_construct(
             function_name='api_lambda_sqs_lambda_dynamodb_subscriber',
             concurrent_executions=2,
             environment_variables={
@@ -78,6 +83,7 @@ class ApiLambdaSqsLambdaDynamodb(well_architected_stack.Stack):
                 'DYNAMODB_TABLE_NAME': dynamodb_table.table_name
             },
         )
+        lambda_function = lambda_construct.lambda_function
         lambda_function.add_event_source(aws_cdk.aws_lambda_event_sources.SqsEventSource(sqs_queue))
         sqs_queue.grant_consume_messages(lambda_function)
         dynamodb_table.grant_read_write_data(lambda_function)
