@@ -11,7 +11,7 @@ class RestApiSnsSqsLambda(well_architected_stack.Stack):
         super().__init__(scope, id, **kwargs)
         self.create_error_topic()
         sns_topic = self.create_sns_topic('The Big Fan CDK Pattern Topic')
-        logging_lambda_function = self.create_lambda_function("big_fan_logger")
+        logging_lambda_function = self.create_lambda_construct("big_fan_logger")
 
         for queue_name, filter_name in (
             ('BigFanTopicStatusCreatedSubscriberQueue', 'allowlist'),
@@ -27,7 +27,7 @@ class RestApiSnsSqsLambda(well_architected_stack.Stack):
                 sqs_queue=sqs_queue,
             )
 
-        well_architected_constructs.rest_api_sns.RestApiSnsConstruct(
+        well_architected_constructs.rest_api_sns.RestApiSns(
             self, 'RestApiSns',
             error_topic=self.error_topic,
             sns_topic_arn=sns_topic.topic_arn,
@@ -73,8 +73,8 @@ class RestApiSnsSqsLambda(well_architected_stack.Stack):
                 aws_cdk.aws_lambda_event_sources.SqsEventSource(sqs_queue)
             )
 
-    def create_lambda_function(self, function_name):
-        return well_architected_constructs.lambda_function.LambdaFunctionConstruct(
+    def create_lambda_construct(self, function_name):
+        return well_architected_constructs.lambda_function.LambdaFunction(
             self, function_name,
             error_topic=self.error_topic,
             lambda_directory=self.lambda_directory,
