@@ -11,7 +11,10 @@ class Stack(aws_cdk.Stack):
         id: str,
         lambda_directory='lambda_functions',
         permissions_boundary_name=None,
-        error_topic=None, **kwargs
+        error_topic=None,
+        create_http_api=False,
+        create_rest_api=False,
+        **kwargs
     ):
         super().__init__(
             scope, id,
@@ -21,6 +24,8 @@ class Stack(aws_cdk.Stack):
         self.id = id
         self.lambda_directory = lambda_directory
         self.error_topic = error_topic
+        self.create_http_api = create_http_api
+        self.create_rest_api = create_rest_api
         self.permissions_boundary = self.add_permissions_boundary(permissions_boundary_name)
 
     def create_sns_topic(self, display_name):
@@ -30,6 +35,7 @@ class Stack(aws_cdk.Stack):
         )
 
     def create_error_topic(self, topic_name=None):
+        # Refactor
         if not self.error_topic:
             if topic_name:
                 display_name = topic_name
@@ -37,7 +43,7 @@ class Stack(aws_cdk.Stack):
                 display_name = f'{self.id}ErrorTopic'
             self.error_topic = self.create_sns_topic(display_name)
 
-    def create_lambda_function(self, function_name=None):
+    def create_lambda_construct(self, function_name=None):
         raise NotImplementedError
 
     def get_vpc(self, vpc_id=None, is_default=None):
@@ -61,4 +67,12 @@ class Stack(aws_cdk.Stack):
                     self, 'PermissionsBoundary',
                     policy_name
                 )
-            )
\ No newline at end of file
+            )
+
+    def create_cloudwatch_dashboard(self, *widgets):
+        return aws_cdk.aws_cloudwatch.Dashboard(
+            self, "CloudWatchDashBoard",
+            widgets=[
+                [widget] for widget in widgets
+            ]
+        )
\ No newline at end of file
